/**
 * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

/**
 * @fileOverview
 */

/**#@+
   @type String
   @example
*/

/**
 * Contains the dictionary of language entries.
 * @namespace
 */
CKEDITOR.lang[ 'sq' ] = {
	// ARIA description.
	editor: 'Redaktues i Pasur Teksti',
	editorPanel: 'Paneli i redaktuesit të tekstit të plotë',

	// Common messages and labels.
	common: {
		// Screenreader titles. Please note that screenreaders are not always capable
		// of reading non-English words. So be careful while translating it.
		editorHelp: 'Shtyp ALT 0 për ndihmë',

		browseServer: 'Shfleto në Server',
		url: 'URL',
		protocol: 'Protokolli',
		upload: 'Ngarko',
		uploadSubmit: 'E dërgo në server',
		image: 'Foto',
		flash: 'Objekt flash',
		form: 'Formulari',
		checkbox: 'Kuti përzgjedhjeje',
		radio: 'Pullë përzgjedhjeje',
		textField: 'Fushë teksti',
		textarea: 'Hapësirë teksti',
		hiddenField: 'Fushë e fshehur',
		button: 'Pullë',
		select: 'Fusha e përzgjedhjeve',
		imageButton: 'Pullë fotografie',
		notSet: '<not set>',
		id: 'Id',
		name: 'Emri',
		langDir: 'Drejtim gjuhe',
		langDirLtr: 'Nga e majta në të djathtë (LTR)',
		langDirRtl: 'Nga e djathta në të majtë (RTL)',
		langCode: 'Kodi i Gjuhës',
		longDescr: 'URL e përshkrimit të hollësishëm',
		cssClass: 'CSS Klasat',
		advisoryTitle: 'Titulli Konsultativ',
		cssStyle: 'Stili',
		ok: 'Mirë',
		cancel: 'Anulo',
		close: 'Mbyll',
		preview: 'Parashih',
		resize: 'Ndrysho madhësinë',
		generalTab: 'Të përgjithshme',
		advancedTab: 'Të përparuara',
		validateNumberFailed: 'Kjo vlerë nuk është numër.',
		confirmNewPage: 'Çdo ndryshim që nuk është ruajtur do humbasë. Je i sigurt që dëshiron të hapsh faqe të re?',
		confirmCancel: 'Ke ndryshuar ca mundësi. Je i sigurt që dëshiron ta mbyllësh dritaren?',
		options: 'Mundësitë',
		target: 'Objektivi',
		targetNew: 'Dritare e re (_blank)',
		targetTop: 'Dritare në plan të parë (_top)',
		targetSelf: 'E njëjta dritare (_self)',
		targetParent: 'Dritarja prind (_parent)',
		langDirLTR: 'Nga e majta në të djathë (LTR)',
		langDirRTL: 'Nga e djathta në të majtë (RTL)',
		styles: 'Stili',
		cssClasses: 'CSS Klasat',
		width: 'Gjerësia',
		height: 'Lartësia',
		align: 'Rreshtimi',
		left: 'Majtas',
		right: 'Djathtas',
		center: 'Në mes',
		justify: 'Zgjero',
		alignLeft: 'Rreshto majtas',
		alignRight: 'Rreshto Djathtas',
		alignCenter: 'Rreshto në mes',
		alignTop: 'Lart',
		alignMiddle: 'Në mes',
		alignBottom: 'Poshtë',
		alignNone: 'Asnjë',
		invalidValue: 'Vlerë e pavlefshme',
		invalidHeight: 'Lartësia duhet të jetë një numër',
		invalidWidth: 'Gjerësia duhet të jetë një numër',
		invalidLength: 'Vlera e përcaktuar për fushën "%1" duhet të jetë pozitive me ose pa njësi matëse me vlerë (%2).',
		invalidCssLength: 'Vlera e fushës "%1" duhet të jetë një numër pozitiv me apo pa njësi matëse të vlefshme CSS (px, %, in, cm, mm, em, ex, pt ose pc).',
		invalidHtmlLength: 'Vlera e fushës "%1" duhet të jetë një numër pozitiv me apo pa njësi matëse të vlefshme HTML (px ose %)',
		invalidInlineStyle: 'Vlera e përcaktuar për stilin e vijëzuar duhet përmbajtur një ose më shumë vlera me format "emër : vlerë", të ndara me pikëpresje.',
		cssLengthTooltip: 'Shto një numër për vlerën në piksel ose një numër me njësi të vlefshme CSS (px, %, in, cm, mm, em, ex, pt, or pc).',

		// Put the voice-only part of the label in the span.
		unavailable: '%1<span class="cke_accessibility">, i padisponueshëm</span>',

		// Keyboard keys translations used for creating shortcuts descriptions in tooltips, context menus and ARIA labels.
		keyboard: {
			8: 'Prapa',
			13: 'Enter',
			16: 'Shift',
			17: 'Ctrl',
			18: 'Alt',
			32: 'Hapësirë',
			35: 'End',
			36: 'Home',
			46: 'Delete',
			112: 'F1',
			113: 'F2',
			114: 'F3',
			115: 'F4',
			116: 'F5',
			117: 'F6',
			118: 'F7',
			119: 'F8',
			120: 'F9',
			121: 'F10',
			122: 'F11',
			123: 'F12',
			124: 'F13',
			125: 'F14',
			126: 'F15',
			127: 'F16',
			128: 'F17',
			129: 'F18',
			130: 'F19',
			131: 'F20',
			132: 'F21',
			133: 'F22',
			134: 'F23',
			135: 'F24',
			224: 'Urdhri'
		},

		// Prepended to ARIA labels with shortcuts.
		keyboardShortcut: 'Shkurtesat e tastierës',

		optionDefault: 'Parazgjedhur'
	}
};
